@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.2
-id: yesod-1.4.2-320e011c17cd5de79d8233919afce0be
-key: yesod_Kn6cmh6It9HISA4cwgdrkd
+id: yesod-1.4.2-717f8b22a84feea8286910a26b644b3b
+key: yesod_I0saYPJmNnn9MrQ03Hp9eb
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,7 +21,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.2
-hs-libraries: HSyesod-1.4.2-Kn6cmh6It9HISA4cwgdrkd
+hs-libraries: HSyesod-1.4.2-I0saYPJmNnn9MrQ03Hp9eb
 depends:
     aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
@@ -36,7 +36,7 @@ depends:
     monad-logger-0.3.18-0974645d267a817a7b3484945a31ce66
     safe-0.3.9-b613242f536083d5bb04920ede356aea
     semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
-    shakespeare-2.0.7-0211859c61478c312aeaa5f154b501d3
+    shakespeare-2.0.8-88acbcac23cb55d5f3c82ebba9b11159
     streaming-commons-0.1.15.2-e8e35f9b3c5e3a1a9d565bf7c4ec1900
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
@@ -48,10 +48,10 @@ depends:
     wai-logger-2.2.4.1-9478a6051df96b8d5b3214f7fcca2185
     warp-3.2.3-6de819de378ae4c57281b63b66004254
     yaml-0.8.16-50dd72d7df25e45cd672d7359cb18648
-    yesod-auth-1.4.12-a6b0c71caf511a065a47faa3af7c7c3f
-    yesod-core-1.4.19-83d7786ccf417e9f8ff12c2ba1e4758e
-    yesod-form-1.4.6-74e09ec1e0cc3b893c314cc7937841de
-    yesod-persistent-1.4.0.3-2e82e69e0978c8663ea0bc70a29c9f56
+    yesod-auth-1.4.12-4d106a89bc5f54fb1850e8a22c0b22dc
+    yesod-core-1.4.19-b6ec8d224ea1c49c36126eee73b10ab6
+    yesod-form-1.4.6-6e5c019f77bbb31f3f8cbc24ba3a758a
+    yesod-persistent-1.4.0.3-c6542cb45d0d37a797eae519cf194b16
 haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
 haddock-html: /usr/share/doc/haskell-yesod/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
